@@ -163,12 +163,14 @@ setMethod("stime", "tgrids", function(x,...) {
 })
 
 render_time <- function(x) {
-  add <- times <- numeric(0)
-  #if(!is.mt(x@add)){add <- x@add}
-  if(x@end >= 0){times <-seq(x@start,x@end,x@delta)}
-  times <- invisible(as.numeric(unique(c(times,x@add))))
-  if(is.mt(times)) {return(0)}
-  sort(times[times>=0])
+  if(x@end < x@start) {
+    return(sort(x@add))
+  }
+  times <- seq(x@start,x@end,x@delta) 
+  if(length(x@add) > 0) {
+    times <- sort(as.numeric(unique(c(times,x@add))))
+  }
+  times[times>=0]
 }
 
 ##' @rdname tgrid
