@@ -182,6 +182,23 @@ as.cvec <- function(x) {
   unlist(strsplit(as.character(x),"\\s*(\n|,|\\s+)\\s*",perl=TRUE))
 }
 
+# collapse a character vector back to length n (undo strsplit)
+collapsen <- function(string,pattern,n=3) {
+    if(length(string) <= n) return(string)
+    if(n==1) return(paste0(string, collapse = pattern))
+    ans <- string[seq(1,(n-1))]
+    if(n >= 2) {
+      remainder <- paste0(string[seq(n,length(string))],collapse=pattern)
+      ans <- c(ans, remainder)  
+    }
+    ans
+}
+
+# replica str_split; to be replace if / when we take up stringr
+my_str_split <- function(string,pattern,n=3,fixed=FALSE) {
+  m <- strsplit(string, pattern, fixed = fixed)
+  lapply(m,collapsen,pattern=pattern,n=n)
+}
 
 ##' Create template data sets for simulation
 ##'
@@ -574,5 +591,3 @@ mod_first <- function(cl) {
 }
 
 
-
-
